# -*- coding: utf-8 -*-
""" db_database

	Defined the tables of your applications.
	Initialized the plugins
	
	$Id$
	
"""
from datetime import datetime

db = DAL('sqlite://storage.sqlite')       # if not, use SQLite or other DB

#===============================================================================
db.define_table("publishers",
	Field("publisher", "string", notnull=True, default=None),
	Field("abbreviation", "string", notnull=True, default=None))

if not db(db.publishers.id).count():
	db.publishers.insert(id=1, publisher='--', abbreviation='')
	db.publishers.insert(publisher='Physics Letter B', 
						 abbreviation='Phys. Lett. B')

#===============================================================================
db.define_table("countries",
	Field("country", "string", notnull=True, default=None),
	Field("abbreviation", "string", notnull=True, default=None))

if not db(db.countries.id).count():
	db.countries.insert(id=1, country='France', abbreviation='FR')

#===============================================================================
db.define_table("teams",
	Field("team", "string", notnull=True, default=None,
										  comment='the name of the team',))

if not db(db.teams.id).count():
  db.teams.insert(id=1, team='--')
  db.teams.insert(team='LHCb')

#===============================================================================
db.define_table("projects",
	Field("project", "string", notnull=True, default=None))

if not db(db.projects.id).count():
	db.projects.insert(id=1, project='--')
	db.projects.insert(project='BigBrothers')

#===============================================================================
db.define_table("categories_commission",
	Field("category", "string", notnull=True, default=None),
	Field("definition", "text", notnull=True, default=None))

if not db(db.categories_commission.id).count():
	db.categories_commission.insert(id=1, category='--', definition='')

#===============================================================================
db.define_table("categories_aeres",
	Field("category", "string", notnull=True, default=None),
	Field("definition", "text", notnull=True, default=None))

if not db(db.categories_aeres.id).count():
	db.categories_aeres.insert(id=1, category='--', definition='')

#===============================================================================
db.define_table("collaborations",
	Field("collaboration", "string", notnull=True, default=None))

if not db(db.collaborations.id).count():
	db.collaborations.insert(id=1, collaboration='--')
	db.collaborations.insert(collaboration='LHCb Collaboration')

#===============================================================================
db.define_table("publications",
	Field("title", "text", notnull=True, default=None,
			                             comment='The title of the publication'),
	Field("authors", "string", notnull=True, 
			                   default=None,
			                   comment='First author, P.-Y. Doe or a list separated by comma'),
	Field("id_collaborations", db.collaborations, label='Collaboration',
												  default=1),
	Field("id_publishers", db.publishers, label='Publisher',
										  default=1),
	Field("year", "integer", notnull=True, default=datetime.now().year),
	Field("volume", "string", length=20, default=None),
	Field("first_page", "integer", default=None),
	Field("last_page", "integer", default=None),
	Field("e_print", "string", default=None),
	Field("conference_title", "text", default=None, label='Title'),
	Field("conference_url", "string", default=None, label='url'),
	Field("conference_start", "date", default=None, label='Start date'),
	Field("conference_end", "date", default=None, label='End date'),
	Field("conference_town", "string", default=None, label='Town'),
	Field("id_countries", db.countries, default=1, label='Country'),
	Field("conference_speaker", "string", default=None, label='Speaker'),
	Field("report_numbers", "string", default=None),
	Field("authors_cppm", "text", notnull=True, default=None),
	Field("id_teams", db.teams, label='Team', default=1),
	Field("id_projects", db.projects, label='Projects', default=1),
	Field("id_categories_commission", db.categories_commission,
									  label='Commission',
									  default=1),
	Field("id_categories_aeres", db.categories_aeres, label='AERES', default=1))

db.publications.id_categories_aeres.requires = \
IS_IN_DB(db, 'categories_aeres.id', 'categories_aeres.category')

db.publications.id_categories_commission.requires = \
IS_IN_DB(db, 'categories_commission.id', 'categories_commission.category')

db.publications.id_collaborations.requires = \
IS_IN_DB(db, 'collaborations.id', 'collaborations.collaboration')

db.publications.id_countries.requires = \
IS_IN_DB(db, 'countries.id', 'countries.country')

db.publications.id_publishers.requires = \
IS_IN_DB(db, 'publishers.id', 'publishers.abbreviation')

db.publications.id_projects.requires = \
IS_IN_DB(db, 'projects.id', 'projects.project')

db.publications.id_teams.requires = IS_IN_DB(db, 'teams.id', 'teams.team')

#===============================================================================
# Define plugin parameters specific to this application
#===============================================================================
from gluon.tools import PluginManager
plugins = PluginManager()
plugins.dbui.script_path = 'static/scripts'
#plugins.dbui.page_view = 'plugin_dbui.html'
#plugins.dbui.with_grid_filter = True