""" $Id$

"""

__version__ = "$Revision$"
__author__ = "R. Le Gac"

import re


# A field name can only contains [a_zA-Z0-9_] according to web2py
table_field = re.compile(r'[\w_]+\.[\w_]+') 
func_table_field = re.compile(r'([A-Z]+)\(([\w_]+)\.([\w_]+)\)')


def decode_field(field):
    """Helper function returning (table, field) or (table, field, func). 

    """ 
    li = []
    for c in field:
        if c.isupper():
            li.append(c.lower())
        else:
            li[-1] += c
    return tuple(li)


def encode_field(*args):
    """Helper function returning TableField, TableFieldFunc.
    
    Note: combobox dont decode properly any separator between 
    table and field like table+field. Therefore choice for the encoding
    are very limited.
    
    Note: dont use the method title since foo_faa becomes Foo_Faa and you
    want Foo_faa.
    
    """ 
    return ''.join([el[0].upper()+el[1:].lower() for el in args if len(el)])


def rows_serializer(rows):
    """Helper function to serialize a gluon.dal.Rows.
    
    Handle the general case where field belongs to different
    table and where function can be applied.
    
        Field are encoded as table_field.
    
        Field with an applied function like COUNT(table.field) 
        are encoded as table_field_count
    
    """
    # Map between column name and TableField
    map = {}
    for col in rows.colnames:
        if not table_field.match(col):
            func, table, field = func_table_field.match(col).groups()
            map[col] = encode_field(table, field, func)
        else:
            table, field = col.split(".")
            map[col] = encode_field(table, field)

    # serialize
    li = []
    for row in rows:
        di = {}
        for col in rows.colnames:
            if not table_field.match(col):
                di[map[col]] = row._extra[col]
            else:
                (table, field) = col.split(".")
                if table in row:
                    di[map[col]] = row[table][field]
                else:
                    di[map[col]] = row[field]
        li.append(di)

    return li