/**
 * The Grid class is a preconfigured version of the GridPanel
 * Many functionality can be added through grid plugins like
 * App.grid.RowEditorContextMenu, ....
 * 
 * The type of this component is xgrid.
 * 
 * @extends Ext.gridPanel
 * @version $Id$
 * 
 */

Ext.namespace('App.grid');

App.grid.Grid = Ext.extend(Ext.grid.GridPanel, {

	/**
	 * @cfg {Object} model Object to configure the widget 
	 * for a table of the database. It is provided by the server 
	 * and contains the following keys:
	 * 	{
	 * 		colModel: [...], 
	 * 		formModel: [...], 
	 * 		store: {}, 
	 * 		table: 'x', 
	 * 		title: 'y', 
	 * 		xtype: 'xgrid'
	 * } 
	 */
	model: null,
	
	/**
	 * pre-defined properties
	 */
	iconCls: 'silk-grid',
	frame: true,
    autoScroll: true,
	autoHeight: true,
	viewConfig: {forceFit: true},

	/**
	 * private 
	 * keep track of RowEditor set by the plugins like 
	 * RowEditorToolBar, RowEditorContextMenu.
	 */
	editor: null,

	/**
	 * private method requests by the component model of Extjs
	 */
	initComponent: function(){

		if (!this.model){
			throw new Error("the property model is missing !!!")
		}

		// grid title
        this.title = this.model.title;
		
		// the data store		
		this.store = new App.data.JsonStore({
			url: App.dburl,
			model: this.model.store,
			debug: App.debug
		});

		// load immediately values in the store
		this.store.load();
		
		// the columns model
		this.columns = this.model.colModel;

		// empty top toolbar/bottomnar -- required by the plugins
		this.tbar = [];
		this.bbar = new Ext.PagingToolbar();
		this.bbar.hide();
		
		// initialize the underlying class. DON'T MOVE
		App.grid.Grid.superclass.initComponent.call(this);
	}
});

Ext.reg('xgrid', App.grid.Grid);
