/**
 * appmgr.js
 * 
 * The application manager class.
 * 
 * The class App.Mgr configure the application and launch it.
 * It is design for database web application.
 * 
 * The layout is a tab widget with a tree panel encapsulated in a viewport.
 * The tree expose two main nodes Forms and Tables. The children of these
 * nodes are the tables of the database.
 *  
 * The class uses the cfgSvc web service to retrieve the tables list 
 * as well as the model for the xentry and xgrid widgets.
 * 
 * The properties of App.Mgr allow to customize the application:
 * 	- the list of tables visible
 * 	- xentry and xgrid widgets
 * 	- ...
 * 
 * $Id$
 * 
 */
Ext.namespace('App');

App.Mgr = Ext.extend(Object, {
	
	/**
	 * constructor of the application manager
	 * @param {Object} config
	 */
	constructor: function(config){
		Ext.apply(this, config);
		App.Mgr.superclass.constructor.apply(this);
		cfgSvc.getTables(this.launch, this);
	},
	
	/**
	 * Call back function to launch the application.
	 * The response should have the property result.
	 * It contains the list of tables available for this web application
	 * 
	 * This method is compatible with the Ext.Direct protocol
	 * http://www.extjs.com/products/extjs/direct.php
	 * 
	 * @param {Object} provider
	 * @param {Object} response
	 */
	launch: function(provider, response){
		
		// list of tables
		var tables = response.result.tables;
	
		/*
		 * Plugin to handle entryForm
		 */
		var formInTree = {
			topNodeName: 'Forms',
			nodesId: tables,
			nodesText: response.result.tablesText,
			tabTitlePrefix: 'Form',
			ptype: 'pInTreeForm',
		};
	
		/*
		 * Plugin to handle grid
		 */	 	
		var tableInTree = {
			topNodeName: 'Tables',
			nodesId: tables,
			nodesText: response.result.tablesText,
			tabTitlePrefix: 'Table',
			ptype: 'pInTreeGrid',
		};
		 
		/*
		 * Pre-configured viewport with a treePanel and a tabPanel
		 */
	
		var cfg = Ext.apply({
			plugins: [formInTree, tableInTree],
		}, App.viewport.cfg.withTreeAndTabPanels);
			
		var viewport= new Ext.Viewport (cfg);
	},
});
